===========
Interaction
===========

A specific type of interaction object and a specific type of interaction state object are designed for each type of interaction. An interaction object stores the non-propagating data of an interaction as well as a number of instances of the corresponding interaction state object, each of which stores the propagating data of the interaction in a single step. Instances of the interaction state object are created and deleted internally by its corresponding interaction object.

Create interactions
-------------------

.. autoclass:: abaqus.Interaction.InteractionModel.InteractionModel
    :members:

    .. autoclasstoc::

.. autoclass:: abaqus.Interaction.InteractionContactControlModel.InteractionContactControlModel
    :members:

    .. autoclasstoc::

.. autoclass:: abaqus.Interaction.InteractionContactInitializationModel.InteractionContactInitializationModel
    :members:

    .. autoclasstoc::

.. autoclass:: abaqus.Interaction.InteractionContactStabilizationModel.InteractionContactStabilizationModel
    :members:

    .. autoclasstoc::

.. autoclass:: abaqus.Interaction.InteractionPropertyModel.InteractionPropertyModel
    :members:

    .. autoclasstoc::


Object features
---------------

ContactControl
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ContactControl.ContactControl
    :members:

    .. autoclasstoc::

ContactDamage
~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ContactDamage.ContactDamage
    :members:

    .. autoclasstoc::

ContactDamping
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ContactDamping.ContactDamping
    :members:

    .. autoclasstoc::

ContactInitialization
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ContactInitialization.ContactInitialization
    :members:

    .. autoclasstoc::

ContactProperty
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ContactProperty.ContactProperty
    :members:

    .. autoclasstoc::

ContactPropertyAssignment
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ContactPropertyAssignment.ContactPropertyAssignment
    :members:

    .. autoclasstoc::

ContactStabilization
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ContactStabilization.ContactStabilization
    :members:

    .. autoclasstoc::

Interaction
~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.Interaction.Interaction
    :members:

    .. autoclasstoc::

InitializationAssignment
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.InitializationAssignment.InitializationAssignment
    :members:

    .. autoclasstoc::

InteractionProperty
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.InteractionProperty.InteractionProperty
    :members:

    .. autoclasstoc::

InteractionState
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.InteractionState.InteractionState
    :members:

    .. autoclasstoc::

AcousticImpedance
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.AcousticImpedance.AcousticImpedance
    :members:

    .. autoclasstoc::

AcousticImpedanceProp
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.AcousticImpedanceProp.AcousticImpedanceProp
    :members:

    .. autoclasstoc::

AcousticImpedanceState
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.AcousticImpedanceState.AcousticImpedanceState
    :members:

    .. autoclasstoc::

ActuatorSensor
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ActuatorSensor.ActuatorSensor
    :members:

    .. autoclasstoc::

ActuatorSensorProp
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ActuatorSensorProp.ActuatorSensorProp
    :members:

    .. autoclasstoc::

ActuatorSensorState
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ActuatorSensorState.ActuatorSensorState
    :members:

    .. autoclasstoc::

CavityRadiation
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.CavityRadiation.CavityRadiation
    :members:

    .. autoclasstoc::

CavityRadiationProp
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.CavityRadiationProp.CavityRadiationProp
    :members:

    .. autoclasstoc::

CavityRadiationState
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.CavityRadiationState.CavityRadiationState
    :members:

    .. autoclasstoc::

CohesiveBehavior
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.CohesiveBehavior.CohesiveBehavior
    :members:

    .. autoclasstoc::

ConcentratedFilmCondition
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ConcentratedFilmCondition.ConcentratedFilmCondition
    :members:

    .. autoclasstoc::

ConcentratedFilmConditionState
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ConcentratedFilmConditionState.ConcentratedFilmConditionState
    :members:

    .. autoclasstoc::

ConcentratedRadiationToAmbient
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ConcentratedRadiationToAmbient.ConcentratedRadiationToAmbient
    :members:

    .. autoclasstoc::

ConcentratedRadiationToAmbientState
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ConcentratedRadiationToAmbientState.ConcentratedRadiationToAmbientState
    :members:

    .. autoclasstoc::

ContactExp
~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ContactExp.ContactExp
    :members:

    .. autoclasstoc::

ContactStd
~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ContactStd.ContactStd
    :members:

    .. autoclasstoc::

ContactTangentialBehavior
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ContactTangentialBehavior.ContactTangentialBehavior
    :members:

    .. autoclasstoc::

CyclicSymmetry
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.CyclicSymmetry.CyclicSymmetry
    :members:

    .. autoclasstoc::

CyclicSymmetryState
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.CyclicSymmetryState.CyclicSymmetryState
    :members:

    .. autoclasstoc::

ElasticFoundation
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ElasticFoundation.ElasticFoundation
    :members:

    .. autoclasstoc::

ElasticFoundationState
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ElasticFoundationState.ElasticFoundationState
    :members:

    .. autoclasstoc::

ExpContactControl
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ExpContactControl.ExpContactControl
    :members:

    .. autoclasstoc::

FilmCondition
~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FilmCondition.FilmCondition
    :members:

    .. autoclasstoc::

FilmConditionProp
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FilmConditionProp.FilmConditionProp
    :members:

    .. autoclasstoc::

FilmConditionState
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FilmConditionState.FilmConditionState
    :members:

    .. autoclasstoc::

FluidCavity
~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FluidCavity.FluidCavity
    :members:

    .. autoclasstoc::

FluidCavityProperty
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FluidCavityProperty.FluidCavityProperty
    :members:

    .. autoclasstoc::

FluidCavityState
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FluidCavityState.FluidCavityState
    :members:

    .. autoclasstoc::

FluidExchange
~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FluidExchange.FluidExchange
    :members:

    .. autoclasstoc::

FluidExchangeProperty
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FluidExchangeProperty.FluidExchangeProperty
    :members:

    .. autoclasstoc::

FluidExchangeState
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FluidExchangeState.FluidExchangeState
    :members:

    .. autoclasstoc::

FluidInflator
~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FluidInflator.FluidInflator
    :members:

    .. autoclasstoc::

FluidInflatorProperty
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FluidInflatorProperty.FluidInflatorProperty
    :members:

    .. autoclasstoc::

FluidInflatorState
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FluidInflatorState.FluidInflatorState
    :members:

    .. autoclasstoc::

FractureCriterion
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.FractureCriterion.FractureCriterion
    :members:

    .. autoclasstoc::

GapElectricalConductance
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.GapElectricalConductance.GapElectricalConductance
    :members:

    .. autoclasstoc::

GapHeatGeneration
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.GapHeatGeneration.GapHeatGeneration
    :members:

    .. autoclasstoc::

GeometricProperties
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.GeometricProperties.GeometricProperties
    :members:

    .. autoclasstoc::

IncidentWave
~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.IncidentWave.IncidentWave
    :members:

    .. autoclasstoc::

IncidentWaveProperty
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.IncidentWaveProperty.IncidentWaveProperty
    :members:

    .. autoclasstoc::

IncidentWaveState
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.IncidentWaveState.IncidentWaveState
    :members:

    .. autoclasstoc::

MasterSlaveAssignment
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.MasterSlaveAssignment.MasterSlaveAssignment
    :members:

    .. autoclasstoc::

ModelChange
~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ModelChange.ModelChange
    :members:

    .. autoclasstoc::

NormalBehavior
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.NormalBehavior.NormalBehavior
    :members:

    .. autoclasstoc::


PressurePenetration
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.PressurePenetration.PressurePenetration
    :members:

    .. autoclasstoc::

PressurePenetrationState
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.PressurePenetrationState.PressurePenetrationState
    :members:

    .. autoclasstoc::

Radiation
~~~~~~~~~

.. autoclass:: abaqus.Interaction.Radiation.Radiation
    :members:

    .. autoclasstoc::

RadiationToAmbient
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.RadiationToAmbient.RadiationToAmbient
    :members:

    .. autoclasstoc::

RadiationToAmbientState
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.RadiationToAmbientState.RadiationToAmbientState
    :members:

    .. autoclasstoc::

RegionPairs
~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.RegionPairs.RegionPairs
    :members:

    .. autoclasstoc::

SelfContactExp
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SelfContactExp.SelfContactExp
    :members:

    .. autoclasstoc::

SelfContactExpState
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SelfContactExpState.SelfContactExpState
    :members:

    .. autoclasstoc::

SelfContactStd
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SelfContactStd.SelfContactStd
    :members:

    .. autoclasstoc::

SelfContactStdState
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SelfContactStdState.SelfContactStdState
    :members:

    .. autoclasstoc::

SlidingTransitionAssignment
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SlidingTransitionAssignment.SlidingTransitionAssignment
    :members:

    .. autoclasstoc::

SmoothingAssignment
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SmoothingAssignment.SmoothingAssignment
    :members:

    .. autoclasstoc::

StabilizationAssignment
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.StabilizationAssignment.StabilizationAssignment
    :members:

    .. autoclasstoc::

StdContactControl
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.StdContactControl.StdContactControl
    :members:

    .. autoclasstoc::

StdInitialization
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.StdInitialization.StdInitialization
    :members:

    .. autoclasstoc::

StdStabilization
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.StdStabilization.StdStabilization
    :members:

    .. autoclasstoc::

StdXplCosimulation
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.StdXplCosimulation.StdXplCosimulation
    :members:

    .. autoclasstoc::

StdXplCosimulationState
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.StdXplCosimulationState.StdXplCosimulationState
    :members:

    .. autoclasstoc::


SurfaceFeatureAssignment
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SurfaceFeatureAssignment.SurfaceFeatureAssignment
    :members:

    .. autoclasstoc::


SurfaceOffsetAssignment
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SurfaceOffsetAssignment.SurfaceOffsetAssignment
    :members:

    .. autoclasstoc::

SurfaceThicknessAssignment
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SurfaceThicknessAssignment.SurfaceThicknessAssignment
    :members:

    .. autoclasstoc::

SurfaceToSurfaceContactExp
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SurfaceToSurfaceContactExp.SurfaceToSurfaceContactExp
    :members:

    .. autoclasstoc::

SurfaceToSurfaceContactStd
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SurfaceToSurfaceContactStd.SurfaceToSurfaceContactStd
    :members:

    .. autoclasstoc::

SurfaceToSurfaceExpState
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SurfaceToSurfaceExpState.SurfaceToSurfaceExpState
    :members:

    .. autoclasstoc::

SurfaceToSurfaceStdState
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.SurfaceToSurfaceStdState.SurfaceToSurfaceStdState
    :members:

    .. autoclasstoc::


ThermalConductance
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.ThermalConductance.ThermalConductance
    :members:

    .. autoclasstoc::

XFEMCrackGrowth
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.XFEMCrackGrowth.XFEMCrackGrowth
    :members:

    .. autoclasstoc::

XFEMCrackGrowthState
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Interaction.XFEMCrackGrowthState.XFEMCrackGrowthState
    :members:

    .. autoclasstoc::

